==> bcalm_2.2.1.orig.tar.gz: bcalm-2.2.1/src/main.cpp <==
/*****************************************************************************
 *   GATB : Genome Assembly Tool Box
 *   Copyright (C) 2014  INRIA
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Affero General Public License as
 *  published by the Free Software Foundation, either version 3 of the
 *  License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Affero General Public License for more details.
 *
 *  You should have received a copy of the GNU Affero General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*****************************************************************************/

// We include the header file for the tool
#include <bcalm_1.hpp>

/********************************************************************************/

/********************************************************************************/

int main (int argc, char* argv[])
{
	
#ifdef GIT_SHA1
	if(argc > 1 && (   strcmp(argv[1],STR_VERSION)==0 || strcmp(argv[1],"-v")==0    )     ){
        std::cout << "BCALM 2, git commit " << GIT_SHA1 << std::endl;
     	std::cout << "Using gatb-core version "<< System::info().getVersion() << std::endl;
		return EXIT_FAILURE;
	}
#endif

    try
    {
        // We run the tool with the provided command line arguments.
        bcalm_1().run (argc, argv);
    }
    catch (Exception& e)
    {
        std::cout << "EXCEPTION: " << e.getMessage() << std::endl;
        return EXIT_FAILURE;
    }

    return EXIT_SUCCESS;
}

==> bcalm_2.2.3.orig.tar.gz: bcalm-2.2.3/src/main.cpp <==
/*****************************************************************************
 *   GATB : Genome Assembly Tool Box
 *   Copyright (C) 2014  INRIA
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Affero General Public License as
 *  published by the Free Software Foundation, either version 3 of the
 *  License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Affero General Public License for more details.
 *
 *  You should have received a copy of the GNU Affero General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*****************************************************************************/

// We include the header file for the tool
#include <bcalm_1.hpp>

/********************************************************************************/

/********************************************************************************/

int main (int argc, char* argv[])
{
	
#ifdef GIT_SHA1
	if(argc > 1 && (   strcmp(argv[1],STR_VERSION)==0 || strcmp(argv[1],"-v")==0    )     ){
        std::cout << "BCALM 2, version " << VERSION << ", git commit " << GIT_SHA1 << std::endl;
     	std::cout << "Using gatb-core version "<< System::info().getVersion() << std::endl;
		return EXIT_SUCCESS;
	}
#endif

    try
    {
        // We run the tool with the provided command line arguments.
        bcalm_1().run (argc, argv);
    }
    catch (Exception& e)
    {
        std::cout << "EXCEPTION: " << e.getMessage() << std::endl;
        return EXIT_FAILURE;
    }

    return EXIT_SUCCESS;
}
